@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2007, 2008, 2009, 2012, 2014, 2015, 2016 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2007, 2008, 2009, 2012, 2014, 2015, 2016, 2018 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -319,6 +319,7 @@ void Board::loadSettings()
 	m_controls_left = settings.value("Controls/Left", Qt::Key_Left).toUInt();
 	m_controls_right = settings.value("Controls/Right", Qt::Key_Right).toUInt();
 	m_controls_flag = settings.value("Controls/Flag", Qt::Key_Space).toUInt();
+	m_controls_hint = settings.value("Controls/Hint", Qt::Key_H).toUInt();
 
 	// Load theme
 	m_theme->load(settings.value("Theme", "Mouse").toString());
@@ -374,6 +375,8 @@ void Board::keyPressEvent(QKeyEvent* event)
 		}
 	} else if (keypress == m_controls_flag) {
 		m_maze->cellMutable(m_player.x(), m_player.y()).toggleFlag();
+	} else if (keypress == m_controls_hint) {
+		hint();
 	} else {
 		return;
 	}
@@ -814,7 +817,7 @@ void Board::renderText(QPainter* painter, const QString& message) const
 	QFont f = font();
 	f.setPointSize(24);
 	QFontMetrics metrics(f);
-	int width = metrics.width(message);
+	int width = metrics.boundingRect(message).width();
 	int height = metrics.height();
 
 	painter->save();
